#!/bin/sh

# # # # #
# Script for merging .pot files with LANG.po ones
#
# Use this to update all the new entries which were inserted on the .pot file, 
# but were not updated on the LANG.po file of the module in question for some reason.
# 
# # # # #


# # # # #
# CHANGELOG:
#
# Version 1.0	
# 06-09-2006	Diego Búrigo Zacarão <diegobz AT gmail DOT com>
#	
#	* Base script created
#
#
# Version 1.0.1	
# 06-09-2006	Igor Pires Soares <igorsoares AT gmail DOT com>
#
#	* LANG.po file permission adjustment added
#
#
# Version 1.0.2	
# 06-10-2006	Diego Búrigo Zacarão <diegobz AT gmail DOT com>
#	
#	* Target file existence control added on permission adjustment
#
#
# Version 1.0.3	
# 06-11-2006	Diego Búrigo Zacarão <diegobz AT gmail DOT com>
#	
#	* Added commit to the server, in case of changes on the .po file
#	(The environment variables CVS_RSH e CVSROOT are defined in the Environment Variable section)
#
# # #


# Parameter Required (pt_BR, pt, en, es, etc...)
if [ -z "$1" ]; then
   echo Use: $0 [LANG]
   echo "Example: $0 pt_BR"
   exit
fi


# Function to set the commit option for the CVS server
MenuCommit() {
   echo -n "Would you like to commit to the server, in case of changes on the .po file?(y/n)"
   read COMMIT

   case $COMMIT in
      "y") echo -n "CVS login:"; read USER; break ;;
      "n") break ;;
      *)  MenuCommit ;;
   esac
}

# Calls MenuCommit
MenuCommit


# It adds the extension to the language (example: pt_BR.po)
LANG="$1.po";

# Variables with complete paths of used programs
SED="/bin/sed"
CP="/bin/cp"
CHMOD="/bin/chmod"
DIFF="/usr/bin/diff"
PWD="/bin/pwd"
MSGMERGE="/usr/bin/msgmerge"
CVS="/usr/bin/cvs"
RM="/bin/rm"

# Environment variables to the CVS
export CVS_RSH="/usr/bin/ssh"
export CVSROOT=":ext:$USER@i18n.redhat.com:/usr/local/CVS"

# It receives the PATH of where the program is running
PATH_PRG=`$PWD`


# It searches for all .pot files as from the running program directory
find ./ -name "*.pot" | sort | while read ORIGEM # while exist .pot files
   do
   
     # It changes the name of the ".pot" file to "pt_BR.po" (for instance) and keeps the file's complete path on "DESTINO"
     DESTINO=`echo ${ORIGEM} | $SED 's/\([a-z\0-9\-]\+.pot\)/'$LANG'/Ig'`

     
     # If the target exist, it enters
     if [ -f ${DESTINO} ]; then

        
     	# It sets permissions to the target file
        $CHMOD u+wr ${DESTINO}


        # It creates a copy of the .po file in question (example: pt_BR.po.bkp)
	$CP -f ${DESTINO} ${DESTINO}.bkp


     	# Sets permissions to the backup file, if it exists
     	if [ -f "${DESTINO}~" ]; then
	    $CHMOD u+wr ${DESTINO}~
     	fi


     	# It prints on the screen how the command will be
     	echo "msgmerge -U ${DESTINO} ${ORIGEM}"

     
     	# The command itself
     	$MSGMERGE -U ${DESTINO} ${ORIGEM}

               
     	# It compares the new merged .po against the .po.bkp copy made previously. In case of changes "COMPARA" will receive a value
     	COMPARA=`$DIFF --brief ${DESTINO} ${DESTINO}.bkp`
	
		
	# If there were changes on the new file, it commits the file to the CVS server
     	if [ -n "${COMPARA}" ]; then
     	
	    echo "######################################"
	    echo "########## There were changes ########"
	    echo "######################################"

	    # It will be displayed only if the answer was "y"
	    if [ ${COMMIT} = "y" ]; then
 
	    	#It takes the directory path of the file in question
            	PATH=`echo ${ORIGEM} | $SED 's/\([a-z\0-9\-]\+.pot\)//Ig'`

	
	    	# It enters to the directory
	    	cd $PATH

	    
	    	# It prints the complete command
	    	echo "cvs commit -m \"Update to ${PATH}\" ${LANG}"

	
	    	# It commits the file to the CVS server
	    	$CVS commit -m "Update to ${PATH}" ${LANG}

	
	    	# It returns to the program's running path
	    	cd $PATH_PRG
	    
	    	# It empties the variable
     	    	COMPARA=""      
	    fi
	    
	else
	    echo "There is no new entries."
	fi
     
        # It brakes a line :P
	echo "" 
        echo "-----------------------------------------------------------------------------------"
	echo ""
        
	#It removes file Backup (.po.bkp)
	#$RM -f ${DESTINO}.bkp
	
     else 
        echo "There is no $LANG file to the following .pot:"
	echo ${ORIGEM}
     fi
	  
   done
